Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJulian Eisel <eiseljulian@gmail.com>2019-09-11 12:37:26 +0300
committerJulian Eisel <eiseljulian@gmail.com>2019-09-11 12:39:58 +0300
commit69e0f485c9f7e75e6e95e66751a5fb29cbe6d4d2 (patch)
tree0b2dbc8740ee6e923f15e050bc90fa8bafb36ef8 /release
parent9bb6058489150a65cc6e3978fb770e4f81474d8b (diff)
Fix T69736: Flipping bookmarks region empties it
Diffstat (limited to 'release')
-rw-r--r--release/scripts/startup/bl_ui/space_filebrowser.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/release/scripts/startup/bl_ui/space_filebrowser.py b/release/scripts/startup/bl_ui/space_filebrowser.py
index 2be5c908269..948a797e7fe 100644
--- a/release/scripts/startup/bl_ui/space_filebrowser.py
+++ b/release/scripts/startup/bl_ui/space_filebrowser.py
@@ -158,8 +158,8 @@ class FILEBROWSER_PT_filter(Panel):
def panel_poll_is_upper_region(region):
- # The upper region is left-aligned, the lower is split into it then.
- return region.alignment == 'LEFT'
+ # The upper region is left-aligned, the lower is split into it then. Note that after "Flip Regions" it's right-aligned.
+ return region.alignment in {'LEFT', 'RIGHT'}
class FILEBROWSER_UL_dir(UIList):